Design Documentation
====================

This section contains design documents, specifications, and implementation plans
for genro-asgi.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   specifications/index
   operational_status/index
   initial_specifications/index
   initial_implementation_plan/index
   plan_2025_12_29/index
